HtmlIntegration

Struct HtmlIntegration 

pub struct HtmlIntegration<'m> { /* private fields */ }
HTML integration.

Builds links, preloads for specified chunks.

// Create `HtmlIntegration` struct:
let html = HtmlIntegration::new(MyViteStatic.boxed())
    // add imports of chunks: (<script> tags)
    .import("src/main.tsx")
    // add preloads of assets (fonts, images, etc).
    // arguments: (preload's as="..." attribute, chunk input filename),
    .preload("image", "src/images/500GB_image.png")
    // add stylesheets
    .stylesheet("src/style.scss")
    // and then, you can build `String` of HTML (tags, joined by '\n')
    .build();
    // or you can build array of tags/lines
    // .build_lines();

// The result will contain `<script>` tags, `<link rel="stylesheet" ...>` for CSS,
// `<link rel="preload" ...>` for image and <link rel="modulepreload" ...> for dependencies.

Implementations

Source

impl<'m> HtmlIntegration<'m>

pub fn new(manifest: DynManifest<'m>) -> Self

Create new HtmlIntegration builder.

Takes DynManifest (boxed Manifest) and returns HtmlIntegration.

pub fn import(self, chunk: &str) -> Self

Import ESM ManifestChunk by key (input filename).

This function:

  • adds <script type="module" ...> for specified chunk;
  • adds module preloads for all script dependencies.
.import("src/main.tsx")
.import("src/components/MyCoolComponent.tsx")
.import("src/or/some/styles.scss")
Panics

This function will panic if:

  • Failed to find chunk by specified key
  • Failed to find dependency (AKA imported chunk)
pub fn preload(self, as_filetype: &'static str, chunk: &str) -> Self

Preload ManifestChunk as type by key (input filename).

.preload("font", "src/assets/CoolFancyFont.ttf")
.preload("image", "src/assets/500GB_image.png")
.preload("script", "src/importantScript.js")
Panics

This function will panic if specified chunk was not found.

pub fn stylesheet(self, chunk: &str) -> Self

Import stylesheet by key (input filename).

.stylesheet("src/style.css")
.stylesheet("src/style.scss")
.stylesheet("src/style.less")
.stylesheet("src/style.whatever")
Panics

This function will panic if specified chunk was not found.

pub fn build_lines(self) -> Vec<String>

Builds HTML and returns array of lines.

let html_lines = HtmlIntegration::new(MyViteStatic.boxed())
    .import("src/main.tsx")
    .build_lines();

assert_eq!(html_lines.len(), 3);
// `src/main.tsx` script tag, `src/shared.ts` preload and `src/style.scss` stylesheet.
pub fn build(self) -> String

Builds HTML and returns String.

let html = HtmlIntegration::new(MyViteStatic.boxed())
    .import("src/main.tsx")
    .build();